Skip to contents

GTTable module that displays tables using DT that are supported by DT::renderDT() and DT::DTOutput().

Value

self

Super class

DarwinShinyModules::ShinyModule -> DTTable

Active bindings

fun

(function) Function to produce a gt table with, i.e gt::gt.

args

(list) Arguments for said function as a named list i.e. list(data = iris).

Methods

Inherited methods


Method new()

Initializer method.

Usage

DTTable$new(fun, args, ...)

Arguments

fun

(function) Function to produce a gt table with, i.e gt::gt.

args

(list()) Arguments for said function as a named list i.e. list(data = iris).

...

Additional parameters to set fields from the ShinyModule parent.


Method clone()

The objects of this class are cloneable with this method.

Usage

DTTable$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

library(DarwinShinyModules)

dtTable <- DTTable$new(
  fun = DT::datatable,
  args = list(data = iris)
)

if (interactive()) {
  preview(dtTable)
}