Skip to contents

Flextable module that displays tables using flextable that are displayed by renderUI and uiOutput.

Value

self

Super class

DarwinShinyModules::ShinyModule -> Flextable

Active bindings

fun

(function) Function to produce a flextable table with, i.e flextable::flextable.

args

(list) Arguments for said function as a named list i.e. list(data = iris).

Methods

Inherited methods


Method new()

Initializer method.

Usage

Flextable$new(fun, args, ...)

Arguments

fun

(function) Function to produce a flextable table with, i.e flextable::flextable.

args

(list()) Arguments for said function as a named list i.e. list(data = iris).

...

Additional parameters to set fields from the ShinyModule parent.


Method clone()

The objects of this class are cloneable with this method.

Usage

Flextable$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

library(DarwinShinyModules)

gtTable <- Flextable$new(
  fun = flextable::flextable,
  args = list(data = iris)
)

if (interactive()) {
  preview(gtTable)
}