Skip to contents

ReactableTable module that displays tables using reactable that are supported by reactable::renderReactable() and reactable::reactableOutput().

Value

self

Super class

DarwinShinyModules::ShinyModule -> ReactableTable

Active bindings

fun

(function) Function to produce a gt table with, i.e gt::gt.

args

(list) Arguments for said function as a named list i.e. list(data = iris).

Methods

Inherited methods


Method new()

Initializer method.

Usage

ReactableTable$new(fun, args, ...)

Arguments

fun

(function) Function to produce a gt table with, i.e gt::gt.

args

(list()) Arguments for said function as a named list i.e. list(data = iris).

...

Additional parameters to set fields from the ShinyModule parent.


Method clone()

The objects of this class are cloneable with this method.

Usage

ReactableTable$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

library(DarwinShinyModules)

reactableTable <- ReactableTable$new(
  fun = reactable::reactable,
  args = list(data = iris)
)

if (interactive()) {
  preview(reactableTable)
}