Skip to contents

Wrapper for rsconnect::deployApp. Deploys a shiny app from the appStructure

Usage

deployAppStructure(
  appStructure,
  appDir = tempfile(),
  launchFun = "launchDarwinBslibApp",
  daemons = 4,
  pkgs = NULL,
  ...
)

Arguments

appStructure

(list: NULL) appStructure object, i.e. a named list of ShinyModule objects or (named) lists containing (named) ShinyModule objects. Representing the navigation (side) bar of the shiny app.

appDir

(character(1): tempfile()) File path to the directory where app files will be written to, and the app is being deployed from. See rsconnect::deployApp for further details.

launchFun

(character(1): "launchDarwinBslibApp") Launch function as character

daemons

(numeric(1): 4) Number of daemons (sub-processes) to launch with the shiny app.

pkgs

(character(n): NULL) Additional packages that should be installed and loaded when deploying.

...

Arguments for rsconnect::deployApp

Value

NULL