launchFromDisk
launchFromDisk.RdLaunches the shiny app from appStructure object from either a qs-file, or
from the object directly, using the provided launchFun. When the qs-file
does not exist, but the appStructure does, the appStructure is saved to
disk, to the provided fileName.
Usage
launchFromDisk(
filePath,
launchFun = DarwinShinyModules::launchDarwinBslibApp,
daemons = 4
)Arguments
- filePath
(
character:"./appStructure.qs") Path to the qs-file, containing theappStructure, or where to write theappStructureto.- launchFun
(
launchFun:DarwinShinyModules::launchDarwinBslibApp) launch function to use, may be any function that launches a shiny app from an appStructure object.- daemons
(
numeric: 2) Number of sub R proccess to kick off to load in results asynchronously.